==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-bg-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Бизнес контакти"

, "Organisation / Unit"
: "Организация / Отдел"

, "Business Address"
: "Адрес на фирмата"

, "Email"
: "Имейл"

, "Telephone Work"
: "Служебен телефон"

, "Telephone Cellphone"
: "Мобилен телефон"

, "Telephone Car"
: "Телефон (кола)"

, "Telephone Fax"
: "Телефонен факс"

, "Telephone Page"
: "Телефонна страница"

, "URL"
: "URL"

, "Role"
: "Длъжност"

, "Room"
: "Стая"

, "Assistant"
: "Асистент"

, "Assistant Telephone"
: "Асистент-телефон"

, "Private Contact Data"
: "Данни за личен контакт"

, "Private Address"
: "Личен адрес"

, "Email Home"
: "Имейл (личен адрес)"

, "Telephone Home"
: "Телефон  (личен номер)"

, "Telephone Cellphone Private"
: "Телефон (личен)"

, "Telephone Fax Home"
: "Факс  (личен номер)"

, "URL Home"
: "URL  (личен адрес)"

, "Other Data"
: "Други данни"

, "Birthday"
: "Дата на раждане"

, "Job Title"
: "Длъжност"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "%s's лични адреси"

, "Lists"
: ""

, "List Roles"
: ""

, "manage shared addressbooks"
: "Споделени списъци на адреси"

, "Create new shared addressbook folders"
: "Създай нови папки за споделени адресни списъци"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: ""

, "Contact, Contacts"
: [
  "Контакт"
 ,"Контакта"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Карта"

, "Personal Information"
: "Персонална информаця"

, "Salutation"
: "Поздрав"

, "Title"
: "Титла"

, "First Name"
: "Име"

, "Middle Name"
: "Бащино име"

, "Last Name"
: "Фамилия"

, "Company"
: "Фирма"

, "Unit"
: "Отдел"

, "Suffix"
: "Допълнително име"

, "Job Role"
: "Длъжност"

, "Display Name"
: "Име"

, "Contact Information"
: "Информаця за контакт"

, "Phone"
: "Телефон"

, "Mobile"
: "Мобилен телефон"

, "Fax"
: "Факс"

, "Phone (private)"
: "Телефон (личен)"

, "Mobile (private)"
: "Мобилен телефон (личен)"

, "Fax (private)"
: "Факс  (личен)"

, "E-Mail"
: "Имейл"

, "E-Mail (private)"
: "Имейл (личен адрес)"

, "Web"
: "Уеб"

, "Company Address"
: "Фирмен адрес"

, "Street"
: "Улица"

, "Street 2"
: "Улица 2"

, "Region"
: "Област"

, "Postal Code"
: "Пощенски код"

, "City"
: "Град"

, "Country"
: "Държава"

, "Description"
: "Описание (допълнителна информаця)"

, "Enter description"
: "Вкарай описание"

, "Export as pdf"
: ""

, "Parse address"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "ID"
: ""

, "Name"
: ""

, "Member of List"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Контакти"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Type"
: "Вид"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Select contact"
: "Избери контакт"

, "Private"
: ""

, "Info"
: ""

, "Insecure link"
: ""

, "Please review this link in edit dialog."
: ""

, "Export {0}, Export {0}"
: [
  ""
 ,""

]
, "Export as PDF"
: "Експортира като pdf"

, "Export as CSV"
: "Експортира като pdf"

, "Export as ODS"
: ""

, "Export as XLS"
: ""

, "Export as DOC"
: ""

, "Export as ..."
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Tags"
: "Тагове"

, "Full Name"
: "Пълно име"

, "Postalcode"
: "Пощенски код"

, "Street (private)"
: "Улица (личен адрес)"

, "City (private)"
: "Град (личен адрес)"

, "Region (private)"
: "Област (приват)"

, "Postalcode (private)"
: "Пощенски код (личен адрес)"

, "Country (private)"
: "Народност (рерсонална)"

, "Car phone"
: "Телефон (кола)"

, "Pager"
: "Пейджер"

, "Email (private)"
: "Имейл (личен адрес)"

, "URL (private)"
: "URL (личена страница)"

, "Note"
: "Бележки"

, "Timezone"
: "Часова зона"

, "Geo"
: "Географско местонахождение / Координати"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Господин"

, "Ms"
: "Госпожа"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "Internal Contacts"
: "Международни контакти"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Contact"
: "Контакт"

, "List Role"
: ""

, "Addressbook"
: ""

, "List"
: ""

, "Email Address"
: ""

, "Export {0}"
: ""

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-bg-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: bg\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Бизнес контакти"

, "Organisation / Unit"
: "Организация / Отдел"

, "Business Address"
: "Адрес на фирмата"

, "Email"
: "Имейл"

, "Telephone Work"
: "Служебен телефон"

, "Telephone Cellphone"
: "Мобилен телефон"

, "Telephone Car"
: "Телефон (кола)"

, "Telephone Fax"
: "Телефонен факс"

, "Telephone Page"
: "Телефонна страница"

, "URL"
: "URL"

, "Role"
: "Длъжност"

, "Room"
: "Стая"

, "Assistant"
: "Асистент"

, "Assistant Telephone"
: "Асистент-телефон"

, "Private Contact Data"
: "Данни за личен контакт"

, "Private Address"
: "Личен адрес"

, "Email Home"
: "Имейл (личен адрес)"

, "Telephone Home"
: "Телефон  (личен номер)"

, "Telephone Cellphone Private"
: "Телефон (личен)"

, "Telephone Fax Home"
: "Факс  (личен номер)"

, "URL Home"
: "URL  (личен адрес)"

, "Other Data"
: "Други данни"

, "Birthday"
: "Дата на раждане"

, "Job Title"
: "Длъжност"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Описание (допълнителна информаця)"

, "Members"
: ""

, "Type"
: "Вид"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "Contact, Contacts"
: [
  "Контакт"
 ,"Контакта"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Държава"

, "City"
: "Град"

, "Postalcode"
: "Пощенски код"

, "Region"
: "Област"

, "Street"
: "Улица"

, "Street 2"
: "Улица 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Народност (рерсонална)"

, "City (private)"
: "Град (личен адрес)"

, "Postalcode (private)"
: "Пощенски код (личен адрес)"

, "Region (private)"
: "Област (приват)"

, "Street (private)"
: "Улица (личен адрес)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Имейл (личен адрес)"

, "Free/Busy URI"
: ""

, "Geo"
: "Географско местонахождение / Координати"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Бележки"

, "Last Name"
: "Фамилия"

, "Display Name"
: "Име"

, "Full Name"
: "Пълно име"

, "First Name"
: "Име"

, "Middle Name"
: "Бащино име"

, "Title"
: "Титла"

, "Suffix"
: "Допълнително име"

, "Company"
: "Фирма"

, "Unit"
: "Отдел"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Длъжност"

, "Salutation"
: "Поздрав"

, "syncBackendIds"
: ""

, "Car phone"
: "Телефон (кола)"

, "Mobile"
: "Мобилен телефон"

, "Mobile (private)"
: "Мобилен телефон (личен)"

, "Fax"
: "Факс"

, "Fax (private)"
: "Факс  (личен)"

, "Phone (private)"
: "Телефон (личен)"

, "Pager"
: "Пейджер"

, "Phone"
: "Телефон"

, "Timezone"
: "Часова зона"

, "Web"
: "Уеб"

, "URL (private)"
: "URL (личена страница)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Информаця за контакт"

, "Company Address"
: "Фирмен адрес"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Тагове"

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "Имейл"

, "E-Mail (private)"
: "Имейл (личен адрес)"

, "Web (private)"
: ""

, "Contacts"
: "Контакти"

, "Addressbooks"
: ""

, "User Account"
: ""

, "Quick Search"
: ""

, "Postal Code"
: "Пощенски код"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Вкарай описание"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "Карта"

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Персонална информаця"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Господин"

, "Ms"
: "Госпожа"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: ""

, "manage shared addressbooks"
: "Споделени списъци на адреси"

, "Create new shared addressbook folders"
: "Създай нови папки за споделени адресни списъци"

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's лични адреси"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Международни контакти"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Bulgarian\nX-Poedit-Country: \nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "Контакт"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
